@@ -12,5 +12,6 @@ def print_list_glws(a):
 		if isinstance(each_items,list):
 			print_list_glws(each_items)
 		else:
-			print(each_items)
+			print(each_items,end ='\t')
+
 
